@@ -33,7 +33,7 @@ function init(aEvent)
   if (/a\d+$/.test(version)) {
     let buildID = Services.appinfo.appBuildID;
     let buildDate = buildID.slice(0,4) + "-" + buildID.slice(4,6) + "-" + buildID.slice(6,8);
-    document.getElementById("version").value += " (" + buildDate + ")";
+    document.getElementById("version").textContent += " (" + buildDate + ")";
   }
 
 //@line 77 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
@@ -49,14 +49,16 @@ function init(aEvent)
 
 //@line 88 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
   gAppUpdater = new appUpdater();
-//@line 90 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
 
-  gChannelSelector.init();
+  let defaults = Services.prefs.getDefaultBranch("");
+  let channelLabel = document.getElementById("currentChannel");
+  channelLabel.value = defaults.getCharPref("app.update.channel");
+//@line 94 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
 
-//@line 98 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
+//@line 100 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
 }
 
-//@line 101 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
+//@line 103 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
 Components.utils.import("resource://gre/modules/AddonManager.jsm");
@@ -531,72 +533,3 @@ appUpdater.prototype =
     return this;
   }
 };
-//@line 576 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/base/content/aboutDialog.js"
-
-var gChannelSelector = {
-  // Disable this UI entirely for now by not including any valid channels
-  validChannels: {},
-  
-  init: function() {
-    try {
-      this.channelValue = Services.prefs.getCharPref("app.update.desiredChannel");
-    } catch (e) {
-      let defaults = Services.prefs.getDefaultBranch("");
-      this.channelValue = defaults.getCharPref("app.update.channel");
-    }
-
-    // Only show channel selector UI on valid update channels.
-    if (this.channelValue in this.validChannels) {
-      document.getElementById("currentChannelText").hidden = false;
-      this.setChannelLabel(this.channelValue);
-      this.setChannelMenuitem(this.channelValue);
-    }
-  },
-
-  selectChannel: function(aSelectedItem) {
-    document.getElementById("channelDescriptionDeck").selectedPanel =
-      document.getElementById(aSelectedItem.value + "Description");
-  },
-
-  cancel: function() {
-    this.setChannelMenuitem(this.channelValue);
-    this.hide();
-  },
-
-  apply: function() {
-    this.channelValue = document.getElementById("channelMenulist").selectedItem.value;
-    this.setChannelLabel(this.channelValue);
-
-    // Change app update channel.
-    Services.prefs.setCharPref("app.update.desiredChannel", this.channelValue);
-
-    // Stop any downloads in progress
-    gAppUpdater.aus.pauseDownload();
-    // App updater will look at app.update.desiredChannel for new channel value
-    // and will clear it when the update is complete.
-    gAppUpdater.isChecking = true;
-    gAppUpdater.checker.checkForUpdates(gAppUpdater.updateCheckListener, true);
-
-    this.hide();
-  },
-
-  show: function() {
-    document.getElementById("contentDeck").selectedPanel =
-      document.getElementById("channelSelector");
-  },
-
-  hide: function() {
-    document.getElementById("contentDeck").selectedPanel =
-      document.getElementById("detailsBox");  
-  },
-
-  setChannelLabel: function(aValue) {
-    let channelLabel = document.getElementById("currentChannel");
-    channelLabel.value = document.getElementById(aValue + "Menuitem").label;
-  },
-
-  setChannelMenuitem: function(aValue) {
-    document.getElementById("channelMenulist").selectedItem =
-      document.getElementById(aValue + "Menuitem");
-  }
-}
